"""
:authors: PavukEdya, Sou1Guard
:license: Apache License, Version 2.0, see LICENSE file

:copyright: (c) 2023 PavukEdya, Sou1Guard
"""

from imagesim import get_median_frame, check_differences

__author__ = 'PavukEdya'
__version__ = '1.0.0'
__email__ = 'slaefir@mail.ru'
